<?php
	//CONTROLADOR ADMIN
	// implementa las operaciones que realiza el administrador
	class Admin extends Controller{

		//OPERACIÓN POR DEFECTO: LISTADO DE USUARIOS
		public function index(){
			$this->listarusuarios();
		}
		
		//METODO QUE LISTA LOS USUARIOS REGISTRADOS EN EL SISTEMA
		public function listarusuarios(){
			//comprobar si el usuario es admin
			if(!Login::isAdmin())
				throw new Exception('Debes ser administrador para acceder');
					
			//recuperar la lista de usuarios y cargar la vista
			$this->datos['usuarios'] = UsuarioModel::getUsuarios();
			$this->load_view('view/admin/lista_usuarios.php');
		}
		
		//PROCEDMIENTO PARA VER LOS DATOS DEL USUARIO
		public function ver($id=0){
			//si no eres administrador... error
			if(!Login::isAdmin())
				throw new Exception('Debes ser administrador para acceder');
		
			//recuperar datos del usuario solicitado
			$u = UsuarioModel::getUsuarioPorId($id);
			
			//si no existe... error
			if(empty($u)) 
				throw new Exception('No existe el usuario indicado');
				
			//mostramos la vista con los datos del usuario
			$this->datos['u'] = $u; //usuario del que se mostrarán los datos
			$this->load_view('view/admin/ver_usuario.php');
		}
		
		
		//PROCEDIMIENTO PARA MODIFICAR LOS DATOS DE UN USUARIO
		public function modificar($id=0){
			//si no eres admin... error
			if(!Login::isAdmin())
				throw new Exception('Debes ser administrador para acceder');
		
			$u = UsuarioModel::getUsuarioPorId($id); //recuperar datos del usuario solicitado
			$this->datos['u'] = $u; //mete el usuario en el array de datos para la vista
			
			//si no existe... error
			if(empty($u)) 
				throw new Exception('No existe el usuario indicado');
						
			//si no llegan los datos a modificar
			if(empty($_POST['modificar'])){
				//mostramos la vista del formulario
				$this->datos['max_image_size'] = Config::get()->user_image_max_size;
				$this->load_view('view/admin/modificar_usuario.php');
					
			//si llegan los datos por POST
			}else{
				$conexion = Database::get();
				
				//recupera los nuevos datos del usuario
				$u->nombre = $conexion->real_escape_string($_POST['nombre']);
				$u->email = $conexion->real_escape_string($_POST['email']);
				$u->admin = empty($_POST['admin'])? 0 : 1;
				$u->privilegio = intval($_POST['privilegio']);
				
				//por si se desea cambiar el password:
				if(!empty($_POST['newpassword']))
					$u->password = MD5($conexion->real_escape_string($_POST['newpassword']));
						
				//por si se desea cambiar la imagen
				if($_FILES['imagen']['error']!=4){
					//el directorio y el tamaño maximo se configuran en el fichero config.php
					$dir = Config::get()->user_image_directory;
					$tam = Config::get()->user_image_max_size;
						
					//prepara la carga de nueva imagen
					$upload = new Upload($_FILES['imagen'], $dir, $tam);
						
					//guarda la imagen antigua en una var para borrarla
					//después si todo ha funcionado correctamente
					$old_img = $u->imagen;
						
					//sube la nueva imagen
					$u->imagen = $upload->upload_image();
				}
	
				//modificar el usuario en BDD
				if(!$u->actualizar())
					throw new Exception('No se pudo modificar');
	
				//borrado de la imagen antigua (si se cambió)
				//hay que evitar que se borre la imagen por defecto
				if(!empty($old_img) && $old_img!= Config::get()->default_user_image)
					@unlink($old_img);
										
				//mostrar los datos del usuario recién modificado
				$this->load_view('view/admin/ver_usuario.php');
			}
		}
		
		
		//PROCEDIMIENTO PARA DAR DE BAJA UN USUARIO
		public function baja($id){
			//si no eres admin... error
			if(!Login::isAdmin())
				throw new Exception('Debes ser administrador para acceder');
		
			//recuperar datos del usuario solicitado
			$u = UsuarioModel::getUsuarioPorId($id);
			
			//si no existe... error
			if(empty($u)) 
				throw new Exception('No existe el usuario indicado');
				
			//si no nos están enviando la conformación de baja
			if(empty($_POST['confirmar'])){
				//carga el formulario de confirmación
				$this->datos['u'] = $u;
				$this->load_view('view/admin/baja_usuario.php');
		
			//si nos están enviando la confirmación de baja
			}else{
				//de borrar el usuario actual en la BDD
				if(!$u->borrar())
					throw new Exception('No se pudo dar de baja');
	
				//borra la imagen (solamente en caso que no sea imagen por defecto)
				if($u->imagen!=Config::get()->default_user_image)
					@unlink($u->imagen);
									
				//cargar la lista de usuarios
				$this->listarusuarios();
			}
		}
	}
?>