<?php
	/* CLASE BASE DE LA QUE HEREDAN LOS CONTROLADORES
	define los métodos de uso general para los controladores que hereden de ella
	es ABSTRACTA, lo que implica que no podremos crear instancias de ella
	
	Todos los controladores dispondrán de las siguientes propiedades útiles para los métodos:
		$this->usuario;  //usuario logueado en el sistema
		$this->datos;  //array de datos que se pasa a las vistas

	*/

	abstract class Controller{
		//PROPIEDADES
		protected $usuario; //usuario logueado en el sistema
		protected $datos; //array de datos que se le pasará a las vistas
		
		//CONSTRUCTOR
		public function __construct(){
			//carga del template para las vistas
			$template = Config::get()->template;
			$this->load('templates/'.$template.'.php');
			
			//recupera el usuario logueado en el sistema
			$this->usuario = Login::getUsuario();
			
			//prepara el array de datos que se pasa a TODAS las vistas
			$this->datos = array(); //crear el array
			$this->datos['template'] = new $template($this->usuario); //se les pasa el template
			$this->datos['usuario'] = $this->usuario; //se les pasa el usuario logueado
		}
		
		
		//METODO PARA CARGAR UN MODELO, CONTROLADOR O LIBRERÍA:
		protected function load($ruta){
			if(!is_readable($ruta)) 
				throw new Exception('No se puede cargar '.$ruta);
			
			require_once($ruta); //carga el fichero
		}
		
		
		//METODO PARA CARGAR UNA VISTA
		//PROTOTIPO: protected void load_view($ruta [,$data]);
		//$ruta: ruta donde se encuentra la vista
		//$data (opcional): array asociativo (u objeto) con los datos que se pasan a la vista
		protected function load_view($ruta, $data=NULL){			
			//si no se encuentra el fichero con la vista...
			if(!is_readable($ruta)) 
				throw new Exception('No se encontró la vista '.$ruta);
			
			$data = empty($data)? $this->datos : $data;	
				
			//remapear los datos del array u objeto de entrada en vars independientes
			if(is_array($data) || is_object($data))
				foreach($data as $clave=>$valor) $$clave = $valor;		
				
			require($ruta); //carga la vista	
		}
	}
?>