<?php
	/* Template.php
	 *
	 * Este fichero contiene una clase con los métodos adecuados para poner cada una de las 
	 * partes que acabarán formando las vistas.
	 * 
	 * Se puede editar para cambiar el aspecto de cada una de las partes o crear clases que hereden de ella.
	 *
	 * Dependencias: --
	 * Se usa en: los métodos de esta clase se usan desde las vistas
	 *
	 * Autor: Robert Sallent
	 * Última revisión: 04/12/2016
	 * */
	class Template{	
		//PROPIEDADES
		//el template contiene los datos del usuario que ha hecho login, de esta forma
		//no es necesario pasárselo a las vistas.
		private $usuario=NULL;
		
		//CONSTRUCTOR
		public function __construct($usuario=NULL){
			$this->usuario = $usuario;
		}
		
		//GETTERS (haciendo uso del método mágico de PHP)
		public function __get($propiedad){
			return $this->propiedad;
		}
				
		/* Métodos para construir partes de la vista de golpe*/
		
		//CONSTRUYE LA PARTE SUPERIOR DE LA VISTA	
		public  function superior(){
			$this->header(); //pone el header
			$this->usuario? $this->logout() : $this->login(); //pone el formulario de login o de logout	
			$this->menu(); //pone el menú
		}
		
		//CONSTRUYE LA PARTE INFERIOR DE LA VISTA
		public  function inferior(){
			$this->footer(); //pone el menú
		}
			
		/* Métodos para construir cada una de las partes de la vista por separado*/
		
		//PONE EL HEADER DE LA PAGINA
		public function header(){	?>
			<header>
				<figure>
					<a href="index.php">
						<img alt="Robs Micro Framework logo" src="images/logos/logo.png" />
					</a>
				</figure>
				<hgroup>
					<h1>RMF - RobS Micro Framework</h1>
					<h2>Para el desarrollo de aplicaciones web</h2>
				</hgroup>
			</header>
		<?php }
		
		
		//PONE EL FORMULARIO DE LOGIN
		public function login(){?>
			<form method="post" id="login" autocomplete="off">
				<input type="text" name="user" required="required" placeholder="usuario" />
				<input type="password" name="password" required="required" placeholder="password" />
				<input type="submit" name="login" value="Login" />
			</form>
		<?php }
		
		
		//PONE LA INFO DEL USUARIO IDENTIFICADO Y EL FORMULARIOD E LOGOUT
		public function logout(){	?>
			<div id="logout">
				<span>Hola 
					<a href="index.php?controlador=Usuario&operacion=ver" title="Mis datos">
					<?php echo $this->usuario->nombre;?></a><?php if($this->usuario->admin) echo ', eres administrador';?>
				</span>							
				<form method="post">
					<input type="submit" name="logout" value="Logout" />
				</form>
			</div>
		<?php }
		
		
		//PONE EL MENU DE LA PAGINA
		public function menu(){ ?>
			<nav>
				<ul class="menu">
					<li><a href="index.php">Inicio</a></li>	
					<?php if($this->usuario){?>
						<li><a href="index.php?controlador=Usuario&operacion=ver">Mis datos</a></li>
					<?php }else{?>
						<li><a href="index.php?controlador=Usuario&operacion=registro">Registro</a></li>
					<?php }?>					
				</ul>
				
				<?php 
				//pone el menú del administrador
				if($this->usuario && $this->usuario->admin){	?>
				<ul class="menu">
					<li><a href="index.php?controlador=admin">ADMIN</a></li>
				</ul>						
				<?php }	?>
				
			</nav>
		<?php }
		
		//PONE EL PIE DE PAGINA
		public function footer(){	?>
			<footer class="flex-container">
					<div class="flex2">
						<p style="margin:20px;">
							<a rel="author" href="http://www.robertsallent.com">Robert Sallent</a>
							<a href="http://www.twitter.com/robertsallent"><img class="logo" alt="twitter logo" src="images/logos/twitter.png" />
						 	</a><a href="https://www.facebook.com/cifovalles">@CIFO'16</a>. 
	         			</p>
	         		</div>
	         		<div class="flex1">
	         			<a href="http://recursos.robertsallent.com/mvc/rmf.zip">
	         				<img id="rmf" src="images/logos/wide.png" alt="RobS Micro Framework Logo" />
	         			</a>
	         		</div>
			</footer>
		<?php }
	}
?>
